## 0.0.47

This new version includes an additional dependency to enhance the functionality of the software.

### New Features

- Added pyzotero as a new dependency to the project (d2214e) (Eric Ma)

### Bug Fixes

- None in this release

### Deprecations

- None in this release
